'use client'
import { jsxs, Fragment, jsx } from 'react/jsx-runtime';
import { useState } from 'react';
import { useTranslation } from 'react-i18next';
import { SocialIcon } from '@dynamic-labs/iconic';
import '@dynamic-labs/sdk-api-core';
import { logger } from '../../shared/logger.js';
import '@dynamic-labs/wallet-connector-core';
import { ReactComponent as SvgDotsHorizontal } from '../../shared/assets/dots-horizontal.js';
import '../../context/ViewContext/ViewContext.js';
import '@dynamic-labs/wallet-book';
import '@dynamic-labs/utils';
import '../../utils/constants/colors.js';
import '../../utils/constants/values.js';
import { providerLabel } from '../../shared/utils/functions/providerLabel/providerLabel.js';
import '../../shared/consts/index.js';
import { classNames } from '../../utils/functions/classNames/classNames.js';
import '../../events/dynamicEvents.js';
import '../../../../_virtual/_tslib.js';
import '../../context/DynamicContext/DynamicContext.js';
import '../../store/state/loadingAndLifecycle/loadingAndLifecycle.js';
import '../../store/state/authMode/authMode.js';
import '../../context/CaptchaContext/CaptchaContext.js';
import '../../context/ErrorContext/ErrorContext.js';
import '@dynamic-labs/multi-wallet';
import 'react-international-phone';
import '../../store/state/nonce/nonce.js';
import '../../store/state/projectSettings/projectSettings.js';
import '../../config/ApiEndpoint.js';
import '../../store/state/user/user.js';
import '../../locale/locale.js';
import '../../store/state/dynamicContextProps/dynamicContextProps.js';
import '../../store/state/primaryWalletId/primaryWalletId.js';
import '../../store/state/connectedWalletsInfo/connectedWalletsInfo.js';
import '../../context/AccessDeniedContext/AccessDeniedContext.js';
import '../../context/AccountExistsContext/AccountExistsContext.js';
import '../../context/UserWalletsContext/UserWalletsContext.js';
import '../../context/VerificationContext/VerificationContext.js';
import 'react-dom';
import '../../utils/functions/compareChains/compareChains.js';
import '../../views/Passkey/utils/findPrimaryEmbeddedChain/findPrimaryEmbeddedChain.js';
import { useIconThemeVariant } from '../../utils/hooks/useIconThemeVariant/useIconThemeVariant.js';
import '../../utils/hooks/useUserUpdateRequest/useUpdateUser/userFieldsSchema.js';
import 'bs58';
import '@dynamic-labs/types';
import '../../context/SocialRedirectContext/SocialRedirectContext.js';
import '../../context/LoadingContext/LoadingContext.js';
import '../../context/WalletContext/WalletContext.js';
import '../../utils/hooks/useEmbeddedWallet/useSecureEnclaveEmbeddedWallet/constants.js';
import 'yup';
import '../../context/MockContext/MockContext.js';
import '../../views/CollectUserDataView/useFields.js';
import '../../context/FieldsStateContext/FieldsStateContext.js';
import '../../context/UserFieldEditorContext/UserFieldEditorContext.js';
import '@dynamic-labs/rpc-providers';
import '../../store/state/walletOptions/walletOptions.js';
import '../Accordion/components/AccordionItem/AccordionItem.js';
import '../Alert/Alert.js';
import { Typography } from '../Typography/Typography.js';
import { Icon } from '../Icon/Icon.js';
import '../ShadowDOM/ShadowDOM.js';
import { IconWithSpinner } from '../IconWithSpinner/IconWithSpinner.js';
import '../IconButton/IconButton.js';
import { IconListTile } from '../IconListTile/IconListTile.js';
import '../InlineWidget/InlineWidget.js';
import '../Input/Input.js';
import '../IsBrowser/IsBrowser.js';
import '../MenuList/Dropdown/Dropdown.js';
import { OverlayCard } from '../OverlayCard/OverlayCard.js';
import '../Transition/ZoomTransition/ZoomTransition.js';
import '../Transition/SlideInUpTransition/SlideInUpTransition.js';
import '../Transition/OpacityTransition/OpacityTransition.js';
import '../PasskeyCreatedSuccessBanner/PasskeyCreatedSuccessBanner.js';
import '../Popper/Popper/Popper.js';
import '../Popper/PopperContext/PopperContext.js';
import 'react-focus-lock';
import 'qrcode';
import '../../context/ThemeContext/ThemeContext.js';
import 'formik';
import '../../utils/hooks/useSubdomainCheck/useSubdomainCheck.js';
import '../../context/WalletGroupContext/WalletGroupContext.js';
import '../../context/IpConfigurationContext/IpConfigurationContext.js';
import '../../context/ConnectWithOtpContext/ConnectWithOtpContext.js';
import '../../widgets/DynamicBridgeWidget/views/WalletsView/components/SecondaryWallets/SecondaryWallets.js';
import '@hcaptcha/react-hcaptcha';
import '../../widgets/DynamicWidget/context/DynamicWidgetContext.js';
import '../../context/FooterAnimationContext/index.js';
import '../../context/ErrorContext/hooks/useErrorText/useErrorText.js';
import '../../context/PasskeyContext/PasskeyContext.js';
import '../../store/state/sendBalances.js';
import '../../store/state/connectorsInitializing/connectorsInitializing.js';
import '../OverlayCardBase/OverlayCardTarget/OverlayCardTarget.js';
import '../../widgets/DynamicWidget/components/DynamicWidgetHeader/DynamicWidgetHeader.js';
import '../../views/TransactionConfirmationView/TransactionConfirmationView.js';
import '../../widgets/DynamicWidget/views/ManagePasskeysWidgetView/PasskeyCard/PasskeyCard.js';
import '../../context/OnrampContext/OnrampContext.js';
import '../../widgets/DynamicWidget/views/ReceiveWalletFunds/ReceiveWalletFunds.js';
import '../../../index.js';
import '../../store/state/tokenBalances.js';
import '../../shared/utils/functions/getInitialUrl/getInitialUrl.js';

const INTERNAL_MAX_INLINE_ITEMS = 5;
const SocialSignIn = ({ providers, onSelectProvider, isLoading, selectedProvider, testId, defaultProvider, numOfItemsToDisplay: externalMaxInlineItems = 5, collapsedLayout, }) => {
    const { t } = useTranslation();
    const iconThemeVariant = useIconThemeVariant();
    // ====================================
    // INLINE VS DEFAULT PROVIDERS
    // ====================================
    // Set default provider as the first available provider if default provider isn't within the providers
    if (defaultProvider && !providers.includes(defaultProvider)) {
        [defaultProvider] = providers;
    }
    /** All enabled providers except the default one */
    const inlineProviders = providers.filter((provider) => provider !== defaultProvider);
    // ====================================
    // ALL PROVIDERS VIEW
    // ====================================
    /** Number of items set in prop, with a max limit of INTERNAL_MAX_INLINE_ITEMS */
    const maxInlineItems = Math.min(externalMaxInlineItems, INTERNAL_MAX_INLINE_ITEMS);
    // Show card button if there are more inline providers than the max
    const showAllProvidersButton = inlineProviders.length > maxInlineItems;
    /** The inline providers that we will show */
    const cappedInlineProviders = showAllProvidersButton
        ? inlineProviders.slice(0, maxInlineItems - 1)
        : inlineProviders.slice(0, maxInlineItems);
    const [showAllProvidersCard, setShowAllProvidersCard] = useState(false);
    const closeAllProvidersCard = () => !isLoading && setShowAllProvidersCard(false);
    // ====================================
    // REACT DISPLAY
    // ====================================
    // Display all with full width if there's only one, or
    // there's no wallet list and 3 social items or less
    const showAllFullWidth = providers.length === 1 || (!collapsedLayout && providers.length < 4);
    const getProviderAsString = (provider) => provider;
    const renderProviderItem = (provider, fullWidth = false, insideCard = false) => (jsxs(IconListTile, { dataTestId: insideCard ? `card-${provider}` : `inline-${provider}`, onClick: () => onSelectProvider(provider), disabled: Boolean(selectedProvider), className: classNames({
            'social-sign-in--card--tile': insideCard,
            'social-sign-in--tile': !insideCard,
            'social-sign-in--tile__full-width': fullWidth,
        }), children: [jsx(IconWithSpinner, { Icon: 
                // eslint-disable-next-line react/jsx-wrap-multilines
                jsx(SocialIcon, { name: getProviderAsString(provider), variant: iconThemeVariant }), isSpinning: selectedProvider === provider, iconSize: 32 }), !insideCard && fullWidth && (jsx(Typography, { variant: 'button_primary', copykey: 'dyn_login.social.button_label', children: t('dyn_login.social.button_label', {
                    provider: providerLabel(provider),
                }) }))] }, getProviderAsString(provider)));
    if (!providers.length) {
        logger.error('Failed to render SocialSignInSection - no social providers enabled');
        return null;
    }
    return (jsxs(Fragment, { children: [jsxs("div", { className: 'social-sign-in', "data-testid": testId, children: [defaultProvider && renderProviderItem(defaultProvider, true), cappedInlineProviders.map((provider) => renderProviderItem(provider, showAllFullWidth)), showAllProvidersButton && (jsx(IconListTile, { dataTestId: 'show-more-options', onClick: () => setShowAllProvidersCard(true), className: 'social-sign-in--tile', children: jsx(Icon, { color: 'text-primary', children: jsx(SvgDotsHorizontal, {}) }) }, 'show-more-options'))] }), jsxs(OverlayCard, { isOpen: showAllProvidersCard, onClose: closeAllProvidersCard, children: [jsx(OverlayCard.Header, { closeDisabled: isLoading, children: t('dyn_login.social.overlay_title') }), jsx(OverlayCard.Content, { className: 'social-sign-in--card--body', children: providers.map((provider) => renderProviderItem(provider, false, true)) })] })] }));
};

export { SocialSignIn };
