'use client'
import { __awaiter } from '../../../../../../_virtual/_tslib.js';
import { useRef, useCallback } from 'react';
import '@dynamic-labs/sdk-api-core';
import '../../../../shared/logger.js';
import '@dynamic-labs/iconic';
import '@dynamic-labs/wallet-connector-core';
import 'react/jsx-runtime';
import '../../../ViewContext/ViewContext.js';
import '@dynamic-labs/wallet-book';
import '@dynamic-labs/utils';
import { CONNECTED_WALLET_NAME_SERVICE } from '../../../../utils/constants/localStorage.js';
import '../../../../utils/constants/colors.js';
import '../../../../utils/constants/values.js';
import { useLocalStorage } from '../../../../shared/utils/hooks/useLocalStorage/useLocalStorage.js';
import '../../../../shared/consts/index.js';
import { getWalletVerifiedCredential } from '../../../../utils/functions/getWalletVerifiedCredential/getWalletVerifiedCredential.js';

const useNameService = ({ currentWallet, user }) => {
    const [connectedNameService, setConnectedNameService, removeConnectedNameService,] = useLocalStorage(CONNECTED_WALLET_NAME_SERVICE, null);
    const lastFetchedNameServiceAddress = useRef();
    const lastFetchedNameServiceNetwork = useRef();
    const fetchNameServiceFromBlockchain = useCallback((wallet) => __awaiter(void 0, void 0, void 0, function* () {
        const { address, connector } = wallet;
        const network = yield connector.getNetwork(true);
        if (address === lastFetchedNameServiceAddress.current &&
            network === lastFetchedNameServiceNetwork.current) {
            return;
        }
        setConnectedNameService(null);
        // store last address used to fetch name service so we can check for it when promise resolves
        // to avoid race conditions
        lastFetchedNameServiceAddress.current = address;
        lastFetchedNameServiceNetwork.current = network;
        let ns;
        try {
            ns = yield wallet.getNameService();
        }
        catch (e) {
            // do nothing
        }
        // only sets name service if the address used to fetch it is the last one used for fetching
        // this avoid issues with promises not resolving in the correct order
        if (lastFetchedNameServiceAddress.current === address &&
            lastFetchedNameServiceNetwork.current === network) {
            setConnectedNameService({
                address,
                avatar: ns === null || ns === void 0 ? void 0 : ns.avatar,
                name: ns === null || ns === void 0 ? void 0 : ns.name,
                network,
            });
            return ns;
        }
        return undefined;
    }), [setConnectedNameService]);
    const getNameService = useCallback((address) => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        if (!currentWallet) {
            return;
        }
        const network = yield currentWallet.connector.getNetwork(true);
        const verifiedCredentials = user === null || user === void 0 ? void 0 : user.verifiedCredentials;
        //if there are verified credentials, check if there is a name service for the current wallet
        if (verifiedCredentials) {
            const verifiedCredential = getWalletVerifiedCredential(currentWallet === null || currentWallet === void 0 ? void 0 : currentWallet.address, verifiedCredentials, currentWallet.chain);
            if (verifiedCredential && ((_a = verifiedCredential.nameService) === null || _a === void 0 ? void 0 : _a.name)) {
                return verifiedCredential.nameService;
            }
        }
        // don't look for name service in blockchain if provided address doesn't match current wallet
        if (address && (currentWallet === null || currentWallet === void 0 ? void 0 : currentWallet.address) !== address) {
            return;
        }
        // if finds name service info in local storage and its related address matches the connected wallet address,
        // return it
        if (connectedNameService &&
            connectedNameService.address === (currentWallet === null || currentWallet === void 0 ? void 0 : currentWallet.address) &&
            connectedNameService.network === network) {
            return {
                avatar: connectedNameService.avatar,
                name: connectedNameService.name,
            };
        }
        // if doesn't find correct name service in verified credentials or local storage, fetch it from blockchain
        return fetchNameServiceFromBlockchain(currentWallet);
    }), [
        currentWallet,
        user === null || user === void 0 ? void 0 : user.verifiedCredentials,
        connectedNameService,
        fetchNameServiceFromBlockchain,
    ]);
    return { getNameService, removeConnectedNameService };
};

export { useNameService };
