'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _tslib = require('../../../../../../_virtual/_tslib.cjs');
var React = require('react');
var utils = require('@dynamic-labs/utils');
require('@dynamic-labs/sdk-api-core');
require('../../../../config/ApiEndpoint.cjs');
require('../../../../store/state/projectSettings/projectSettings.cjs');
require('../../../../utils/constants/values.cjs');
require('@dynamic-labs/multi-wallet');
require('../../../../shared/logger.cjs');
require('../../../../utils/constants/colors.cjs');
require('react-international-phone');
require('@dynamic-labs/iconic');
require('@dynamic-labs/wallet-connector-core');
require('react/jsx-runtime');
require('../../../ViewContext/ViewContext.cjs');
require('@dynamic-labs/wallet-book');
require('../../../../shared/consts/index.cjs');
require('../../../../store/state/nonce/nonce.cjs');
var dynamicContextProps = require('../../../../store/state/dynamicContextProps/dynamicContextProps.cjs');
var primaryWalletId = require('../../../../store/state/primaryWalletId/primaryWalletId.cjs');
var user = require('../../../../store/state/user/user.cjs');
var connectedWalletsInfo = require('../../../../store/state/connectedWalletsInfo/connectedWalletsInfo.cjs');
require('../../../../locale/locale.cjs');
var wallets = require('../../../../data/api/wallets/wallets.cjs');
var UserWalletsContext = require('../../../UserWalletsContext/UserWalletsContext.cjs');
var authMode = require('../../../../store/state/authMode/authMode.cjs');

const useRemoveWallet = ({ secondaryWallets, handleLogOut, setPrimaryWallet, }) => {
    const { removedWalletsIds, userWallets } = UserWalletsContext.useInternalUserWallets();
    const connectedWalletsInfo$1 = connectedWalletsInfo.useConnectedWalletsInfo();
    const nextWalletId = React.useMemo(() => (secondaryWallets[0] ? secondaryWallets[0].id : undefined), [secondaryWallets]);
    const callback = React.useCallback((walletId) => _tslib.__awaiter(void 0, void 0, void 0, function* () {
        var _a;
        const wallet = userWallets.find((w) => w.id === walletId);
        if (!wallet)
            return;
        const primaryWalletId$1 = primaryWalletId.getPrimaryWalletId();
        const isUnlinkingPrimaryWallet = walletId === primaryWalletId$1;
        const authMode$1 = authMode.getAuthMode();
        if (authMode$1 === 'connect-and-sign') {
            const isLastVerifiedCredential = ((_a = user.getUser()) === null || _a === void 0 ? void 0 : _a.verifiedCredentials.length) === 1;
            if (isLastVerifiedCredential) {
                throw new utils.DynamicError('This is your only login method. Add another wallet or log in method before removing it.');
            }
            yield wallets.unlinkWallet({
                environmentId: dynamicContextProps.getEnvironmentId(),
                onSuccess: () => {
                    removedWalletsIds.current.push(walletId);
                },
                // primaryWalletId is the suggestion of the next credential to be set as lastVerifiedCredential
                // If we're unlinking the primary wallet, we don't want to set it to that!
                primaryWalletId: isUnlinkingPrimaryWallet
                    ? undefined
                    : primaryWalletId$1,
                walletId,
            });
        }
        else {
            removedWalletsIds.current.push(walletId);
        }
        const updatedConnectedWalletsInfo = connectedWalletsInfo$1.filter((wallet) => wallet.id !== walletId);
        connectedWalletsInfo.setConnectedWalletsInfo(updatedConnectedWalletsInfo);
        if (isUnlinkingPrimaryWallet) {
            if (nextWalletId)
                setPrimaryWallet(nextWalletId);
            else
                handleLogOut();
        }
        const numberOfWalletsWithSameConnector = userWallets.filter(({ connector }) => connector.key === wallet.connector.key).length;
        // If there's only 1, it's the one being removed and we can kill the session
        if (numberOfWalletsWithSameConnector === 1) {
            yield wallet.connector.endSession();
        }
    }), [
        userWallets,
        connectedWalletsInfo$1,
        nextWalletId,
        removedWalletsIds,
        setPrimaryWallet,
        handleLogOut,
    ]);
    return callback;
};

exports.useRemoveWallet = useRemoveWallet;
