'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

require('@dynamic-labs/sdk-api-core');
require('../../../../shared/logger.cjs');
require('@dynamic-labs/iconic');
require('@dynamic-labs/wallet-connector-core');
require('react');
require('react/jsx-runtime');
require('../../../ViewContext/ViewContext.cjs');
require('@dynamic-labs/wallet-book');
var isSSR = require('../../../../shared/utils/functions/isSSR/isSSR.cjs');
require('@dynamic-labs/utils');
require('../../../../utils/constants/colors.cjs');
require('../../../../utils/constants/values.cjs');
require('../../../../shared/consts/index.cjs');

const findOrCreateLinkTag = () => {
    if (isSSR.isSSR())
        return;
    const existingStyleTag = document.querySelector('[data-source="dynamic-theme-cdn"]');
    if (existingStyleTag) {
        return existingStyleTag;
    }
    const linkTag = document.createElement('link');
    document.head.append(linkTag);
    linkTag.dataset.source = 'dynamic-theme-cdn';
    linkTag.rel = 'stylesheet';
    return linkTag;
};
const findOrCreateStyleTag = () => {
    if (isSSR.isSSR())
        return;
    const existingStyleTag = document.querySelector('[data-source="dynamic-theme"]');
    if (existingStyleTag) {
        return existingStyleTag;
    }
    const styleTag = document.createElement('style');
    document.head.append(styleTag);
    styleTag.dataset.source = 'dynamic-theme';
    return styleTag;
};
const buildStylesheet = (theme) => {
    const { customColor, brandStyle } = theme;
    const footerBackgroundColor = brandStyle === 'bold' ? customColor : undefined;
    const footerIconColor = brandStyle === 'subtle' ? customColor : undefined;
    const cssAttributes = [
        ['--dynamic-brand-primary-color', customColor],
        ['--dynamic-badge-dot-background', customColor],
        ['--dynamic-footer-background-color', footerBackgroundColor],
        ['--dynamic-footer-icon-color', footerIconColor],
    ];
    return `@layer dynamic-project-environment-theme {
  #dynamic-widget, #dynamic-modal, .dynamic-shadow-dom {
    ${cssAttributes
        .filter(([, value]) => value !== undefined && value !== '')
        .map(([key, value]) => `${key}: ${value};`)
        .join('\n    ')}
  }
}`;
};

exports.buildStylesheet = buildStylesheet;
exports.findOrCreateLinkTag = findOrCreateLinkTag;
exports.findOrCreateStyleTag = findOrCreateStyleTag;
