'use client'
import { SDKApi, Configuration } from '@dynamic-labs/sdk-api-core';
import { FetchService } from '@dynamic-labs/utils';
import { VERSION, API_VERSION } from '../../../version.js';
import ApiEndpoint from '../../config/ApiEndpoint.js';
import { isGlobalWalletPopup } from '../../shared/utils/functions/isGlobalWalletPopup/isGlobalWalletPopup.js';
import { getProjectSettings } from '../../store/state/projectSettings/projectSettings.js';
import '../../utils/constants/values.js';
import '../../../../_virtual/_tslib.js';
import '@dynamic-labs/multi-wallet';
import '../../shared/logger.js';
import '../../utils/constants/colors.js';
import { getMinAuthToken } from '../../utils/functions/getMinAuthToken/getMinAuthToken.js';
import 'react-international-phone';
import { getDeviceFingerprint } from '../../utils/functions/getDeviceFingerprint/getDeviceFingerprint.js';
import '@dynamic-labs/iconic';
import '@dynamic-labs/wallet-connector-core';
import 'react';
import 'react/jsx-runtime';
import '../../context/ViewContext/ViewContext.js';
import '@dynamic-labs/wallet-book';
import '../../shared/consts/index.js';
import '../../store/state/nonce/nonce.js';
import { randomString } from '../../utils/functions/randomString/randomString.js';
import { isCookieEnabled } from '../../utils/functions/isCookieEnabled/isCookieEnabled.js';
import '../../store/state/user/user.js';
import '../../locale/locale.js';
import '../../store/state/dynamicContextProps/dynamicContextProps.js';
import '../../store/state/primaryWalletId/primaryWalletId.js';
import '../../store/state/connectedWalletsInfo/connectedWalletsInfo.js';

const sdkApi = ({ customHeaders } = {}) => {
    const settings = {
        basePath: ApiEndpoint.getBaseUrl(),
        headers: Object.assign({ 'Content-Type': 'application/json', 'x-dyn-request-id': randomString(50) }, customHeaders),
    };
    const minJwt = getMinAuthToken();
    if (minJwt) {
        settings.headers.Authorization = `Bearer ${minJwt}`;
    }
    const deviceFingerprint = getDeviceFingerprint();
    if (deviceFingerprint) {
        settings.headers['x-dyn-device-fingerprint'] = deviceFingerprint;
    }
    const projectSettings = getProjectSettings();
    const credentials = projectSettings && isCookieEnabled(projectSettings) ? 'include' : undefined;
    settings.headers['x-dyn-version'] = `WalletKit/${VERSION}`;
    settings.headers['x-dyn-api-version'] = `API/${API_VERSION}`;
    settings.headers['x-dyn-is-global-wallet-popup'] = isGlobalWalletPopup()
        ? 'true'
        : 'false';
    return new SDKApi(new Configuration(Object.assign(Object.assign({}, settings), { credentials, fetchApi: FetchService.fetch })));
};

export { sdkApi };
