'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _tslib = require('../../../../../_virtual/_tslib.cjs');
var sdkApiCore = require('@dynamic-labs/sdk-api-core');
var utils$1 = require('@dynamic-labs/utils');
var api = require('../api.cjs');
var utils = require('../utils.cjs');

const getUserMfaDevices = (_a) => _tslib.__awaiter(void 0, [_a], void 0, function* ({ environmentId, }) {
    try {
        const { devices } = yield api.sdkApi().getUserMfaDevices({
            environmentId,
        });
        return devices;
    }
    catch (e) {
        yield utils.logResponseError(e, 'Error getting mfa devices');
        return [];
    }
});
const addMfaDevice = (_b) => _tslib.__awaiter(void 0, [_b], void 0, function* ({ environmentId, type, }) {
    try {
        if (type === sdkApiCore.MFADeviceType.Totp) {
            const response = yield api.sdkApi().registerTotpMfaDevice({
                environmentId,
            });
            return response;
        }
        throw new Error('Unsupported MFA device type');
    }
    catch (e) {
        const responseError = yield utils.logResponseError(e, 'Error adding mfa device');
        const message = e instanceof Error ? e.message : responseError.error;
        throw new Error(message);
    }
});
const updateUserMfaDevice = (_c) => _tslib.__awaiter(void 0, [_c], void 0, function* ({ environmentId, mfaDeviceId, }) {
    try {
        yield api.sdkApi().updateUserMfaDevice({
            environmentId,
            mfaDeviceId,
        });
    }
    catch (e) {
        yield utils.logResponseError(e, 'Error updating mfa device');
    }
});
const deleteMfaDevice = (_d) => _tslib.__awaiter(void 0, [_d], void 0, function* ({ environmentId, mfaDeviceId, mfaAuthToken, }) {
    try {
        yield api.sdkApi().deleteMfaDevice({
            environmentId,
            mfaDeviceId,
            xMfaAuthToken: mfaAuthToken,
        });
    }
    catch (e) {
        yield utils.logResponseError(e, 'Error delete mfa device');
    }
});
// used when verifying a device added after the user is already logged in
// no jwt update needed
const verifyMfaDevice = (_e) => _tslib.__awaiter(void 0, [_e], void 0, function* ({ environmentId, type, code, }) {
    try {
        if (type === sdkApiCore.MFADeviceType.Totp) {
            const request = {
                code,
                type,
            };
            const device = yield api.sdkApi().registerTotpMfaDeviceVerify({
                environmentId,
                mFARegisterTotpDevicePostRequest: request,
            });
            return device;
        }
        throw new Error('Unsupported MFA device type');
    }
    catch (e) {
        yield utils.logResponseError(e, 'Error verify mfa device');
        return undefined;
    }
});
// used when verifying a device when user is logging in
// jwt update needed
const authMfaDevice = (_f) => _tslib.__awaiter(void 0, [_f], void 0, function* ({ deviceId, environmentId, type, code, createMfaToken, }) {
    try {
        if (type === sdkApiCore.MFADeviceType.Totp) {
            const request = {
                code,
                createMfaToken,
                id: deviceId || undefined,
            };
            const response = yield api.sdkApi().authMfaTotpDevice({
                environmentId,
                mFAAuthTotpDevicePostRequest: request,
            });
            return response;
        }
        throw new Error('Unsupported MFA device type');
    }
    catch (error) {
        const responseError = yield utils.logResponseError(error, 'Error auth mfa devices');
        if (error instanceof Response) {
            if (responseError.code === 'mfa_invalid_code') {
                throw new utils$1.MfaInvalidOtpError();
            }
            if (responseError.code === 'mfa_rate_limited') {
                throw new utils$1.MfaRateLimitedError();
            }
        }
        throw error;
    }
});
const getRecoveryCodes = (_g) => _tslib.__awaiter(void 0, [_g], void 0, function* ({ environmentId, }) {
    try {
        const { recoveryCodes } = yield api.sdkApi().getRecoveryCodes({
            environmentId,
        });
        return recoveryCodes;
    }
    catch (e) {
        yield utils.logResponseError(e, 'Error get mfa recovery codes');
        return [];
    }
});
const createNewRecoveryCodes = (_h) => _tslib.__awaiter(void 0, [_h], void 0, function* ({ environmentId, }) {
    try {
        const { recoveryCodes } = yield api.sdkApi().createNewRecoveryCodes({
            environmentId,
        });
        return recoveryCodes;
    }
    catch (e) {
        yield utils.logResponseError(e, 'Error create mfa recovery codes');
        return [];
    }
});
// used when verifying a device when user is logging in with recovery code
// jwt update needed
const authMfaRecovery = (_j) => _tslib.__awaiter(void 0, [_j], void 0, function* ({ environmentId, code, }) {
    try {
        const request = {
            code,
        };
        const response = yield api.sdkApi().authMfaRecovery({
            environmentId,
            mFAAuthRecoveryDevicePostRequest: request,
        });
        return response;
    }
    catch (error) {
        const responseError = yield utils.logResponseError(error, 'Error mfa recovery');
        if (error instanceof Response) {
            if (responseError.code === 'mfa_invalid_code') {
                throw new utils$1.MfaInvalidOtpError();
            }
        }
        throw error;
    }
});

exports.addMfaDevice = addMfaDevice;
exports.authMfaDevice = authMfaDevice;
exports.authMfaRecovery = authMfaRecovery;
exports.createNewRecoveryCodes = createNewRecoveryCodes;
exports.deleteMfaDevice = deleteMfaDevice;
exports.getRecoveryCodes = getRecoveryCodes;
exports.getUserMfaDevices = getUserMfaDevices;
exports.updateUserMfaDevice = updateUserMfaDevice;
exports.verifyMfaDevice = verifyMfaDevice;
