'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _tslib = require('../../../../../_virtual/_tslib.cjs');
require('@dynamic-labs/sdk-api-core');
var logger = require('../../../shared/logger.cjs');
require('@dynamic-labs/iconic');
require('@dynamic-labs/wallet-connector-core');
require('react');
require('react/jsx-runtime');
require('../../../context/ViewContext/ViewContext.cjs');
require('@dynamic-labs/wallet-book');
require('@dynamic-labs/utils');
require('../../../utils/constants/colors.cjs');
require('../../../utils/constants/values.cjs');
require('../../../shared/consts/index.cjs');
var api = require('../api.cjs');
var helpers = require('../../../context/DynamicContext/helpers/helpers.cjs');
var version = require('../../../../version.cjs');

const fetchProjectSettings = (environmentId) => _tslib.__awaiter(void 0, void 0, void 0, function* () {
    try {
        const res = yield api.sdkApi().getEnvironmentSettings({
            environmentId,
            sdkVersion: `WalletKit/${version.VERSION}`,
        }, {
            credentials: 'omit',
        });
        return res;
    }
    catch (e) {
        logger.logger.error(e);
        return undefined;
    }
});
/**
 * Detects circular references in an object, and replaces them with a string
 * This ensures we can JSON stringify the object without errors
 *
 * @param obj
 * @returns obj mutated object with circular references replaced
 */
const detectCircular = (obj) => {
    const seen = new WeakMap();
    const _recursive = (obj, parentKey = '') => {
        for (const key in obj) {
            const thisKey = parentKey + (parentKey === '' ? '' : '.') + key;
            if (typeof obj[key] === 'object') {
                if (seen.has(obj[key])) {
                    const seenKey = seen.get(obj[key]);
                    obj[key] = `[Circular Reference => ${seenKey}]`;
                    continue;
                }
                seen.set(obj[key], thisKey);
                _recursive(obj[key], thisKey);
            }
        }
        return obj;
    };
    return _recursive(obj);
};
const sendDynamicProps = (environmentId, settingsToSend) => _tslib.__awaiter(void 0, void 0, void 0, function* () {
    try {
        const { dynamicContextProps, dynamicWagmiSettings, frameworkSettings } = settingsToSend;
        if (dynamicContextProps) {
            yield sendDynamicContextSettings(environmentId, { dynamicContextProps, frameworkSettings }, helpers.isDynamicContextSessionSettingExpired, helpers.setDynamicContextSessionSettings);
        }
        if (dynamicWagmiSettings) {
            yield sendDynamicContextSettings(environmentId, { dynamicWagmiSettings }, helpers.isWagmiSessionSettingExpired, helpers.setWagmiSessionSettings);
        }
    }
    catch (error) {
        logger.logger.warn('Error caught when sending sdkSettings to api. Please notify Dynamic, and send the DynamicContextProvider settings you currently have configured', { error });
    }
});
const sendDynamicContextSettings = (environmentId, sdkSettingsRequest, isSdkSettingExpired, setSDKSessionSettings) => _tslib.__awaiter(void 0, void 0, void 0, function* () {
    // sent once. no need to send again
    if (!isSdkSettingExpired()) {
        return;
    }
    yield api.sdkApi().logDynamicSdkSettings({
        environmentId,
        sdkSettingsRequest: detectCircular(sdkSettingsRequest),
    });
    setSDKSessionSettings();
});

exports.fetchProjectSettings = fetchProjectSettings;
exports.sendDynamicProps = sendDynamicProps;
