import { ReactElement } from 'react';
import { OauthProviderRequest, PasswordSourceTypeEnum, WalletAdditionalAddress, WalletProviderEnum } from '@dynamic-labs/sdk-api-core';
import type { InternalWalletConnector, Wallet } from '@dynamic-labs/wallet-connector-core';
export type { Wallet } from '@dynamic-labs/wallet-connector-core';
export type WalletAction = 'select' | 'unlink';
export type WalletWithAction = {
    action: WalletAction;
    wallet: Wallet;
};
/** Defines the options that show in our log in wallet lists */
export interface WalletOption {
    isInstalledOnBrowser: boolean;
    key: string;
    name: string;
    walletConnector: InternalWalletConnector;
    group?: string;
    chainGroup?: string;
    walletGroup?: string;
    groupedWallets?: WalletOption[];
    injectedConfig?: Array<Record<string, unknown>>;
}
export type WalletGroupOption = WalletOption & {
    groupedWallets: WalletOption[];
};
export type WalletGroup = {
    key: string;
    name: string;
    brand?: {
        primaryColor?: string;
        icon?: string;
    };
};
export type WalletGroups = {
    [key: string]: WalletGroup;
};
export type WalletProvider = `${WalletProviderEnum}`;
export interface VerifyWallet {
    captchaToken?: string;
    chain: string | undefined;
    messageToSign: string;
    network: string | number | undefined;
    oauth?: OauthProviderRequest;
    publicWalletAddress: string;
    signedMessage: string;
    skipEmptyAccountCheck?: boolean;
    walletName: string;
    walletProvider: WalletProvider;
    additionalWalletAddresses?: WalletAdditionalAddress[];
    backup?: string;
    password?: string;
    passwordSource?: PasswordSourceTypeEnum;
    sessionPublicKey?: string;
}
export type RecommendedWallet = {
    walletKey: string;
    label?: string;
};
export type ChainToWalletMap = {
    primary_chain: string;
    wallets: {
        algorand?: string;
        bitcoin?: string;
        cosmos?: string;
        evm?: string;
        flow?: string;
        solana?: string;
    };
};
export type WalletsFilter = (options: WalletOption[]) => WalletOption[];
export type WalletListViewTabItem = {
    label: {
        /**
         * Text that will be displayed in the tab
         */
        text?: string;
        /**
         * Icon that will be displayed in the tab
         */
        icon?: string | ReactElement;
        /**
         * Optional key that can be used to identify the tab in events such as `walletTabSelected`
         */
        key?: string;
    };
    walletsFilter?: WalletsFilter;
    recommendedWallets?: RecommendedWallet[];
};
