'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

require('@dynamic-labs/sdk-api-core');
require('../../../logger.cjs');
require('@dynamic-labs/iconic');
require('@dynamic-labs/wallet-connector-core');
require('react');
require('react/jsx-runtime');
require('../../../../context/ViewContext/ViewContext.cjs');
require('@dynamic-labs/wallet-book');
var isSSR = require('../../functions/isSSR/isSSR.cjs');
require('@dynamic-labs/utils');
require('../../../../utils/constants/colors.cjs');
require('../../../../utils/constants/values.cjs');

/**
 * Prefetches a resource
 * Adds a link element to the head of the document with the provided attributes
 * when the element is not already present
 * @param {PrefetchProps} prefetchProps
 * @returns {void}
 *
 * @example
 * usePrefetch({
 *  href: 'https://example.com/image.jpg',
 *  as: 'image',
 *  type: 'image/jpeg',
 *  id: 'image-prefetch',
 * });
 */
const usePrefetch = ({ as, href, id, type }) => {
    // Do not run on server side
    if (isSSR.isSSR())
        return;
    const predefinedElement = document.head.querySelector(`#${id}`);
    // Do not add the element if it already exists
    if (predefinedElement)
        return;
    const element = document.createElement('link');
    element.setAttribute('id', id);
    element.setAttribute('rel', 'prefetch');
    element.setAttribute('href', href);
    element.setAttribute('as', as);
    element.setAttribute('type', type);
    document.head.insertAdjacentElement('beforeend', element);
};

exports.usePrefetch = usePrefetch;
