'use client'
import { AuthStorageEnum } from '@dynamic-labs/sdk-api-core';
import { assertDefined, PlatformService } from '@dynamic-labs/utils';

const isCookieEnabled = (projectSettings) => {
    var _a, _b;
    assertDefined(projectSettings, 'projectSettings is required');
    /**
     * There is no cookie on native mobile applications
     * so this feature must be disabled for native mobile
     */
    if (PlatformService.isNativeMobile) {
        return false;
    }
    const securitySettings = projectSettings.security;
    if (!securitySettings)
        return false;
    // client uses Dynamic cookies
    const dynamicCookiesEnabled = (((_a = securitySettings.auth) === null || _a === void 0 ? void 0 : _a.storage) || []).includes(AuthStorageEnum.Cookie);
    // BYO JWT client puts their non-Dynamic JWT in a cookie
    const byoJwtCookieEnabled = Boolean((_b = securitySettings.externalAuth) === null || _b === void 0 ? void 0 : _b.cookieName);
    // should return true for both of these scenarios
    // because we also need to do `credentials: true` in api.ts when
    // a byo jwt client sets their named cookie for their jwt and
    // needs to send it to our backend
    return dynamicCookiesEnabled || byoJwtCookieEnabled;
};

export { isCookieEnabled };
