'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var utils = require('@dynamic-labs/utils');
var localStorage$1 = require('../../constants/localStorage.cjs');

const useClearWalletConnectSessions = ({ connectors }) => {
    const clearAllWalletConnectSessions = React.useCallback(() => {
        if (typeof window === 'undefined')
            return;
        for (const key of utils.StorageService.getKeys()) {
            if (key.startsWith('walletconnect') ||
                key.startsWith('walletlink') ||
                key.startsWith('wc@2')) {
                localStorage.removeItem(key);
            }
        }
        // remove embedded wallet session iframe
        connectors === null || connectors === void 0 ? void 0 : connectors.forEach((connector) => {
            var _a, _b, _c;
            if ((_b = (_a = connector === null || connector === void 0 ? void 0 : connector.name) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === null || _b === void 0 ? void 0 : _b.startsWith('turnkey')) {
                (_c = connector
                    .getAuthenticatorHandler()) === null || _c === void 0 ? void 0 : _c.clear();
                utils.StorageService.removeItem(localStorage$1.EMBEDDED_WALLET_SESSION_SETTINGS);
                utils.StorageService.removeItem(localStorage$1.EMBEDDED_WALLET_SECURE_BANNER);
            }
        });
    }, [connectors]);
    // Clears orphaned wallet connect sessions
    React.useEffect(() => {
        if (typeof window === 'undefined')
            return;
        if (connectors.length === 0)
            return;
        const keys = new Set(connectors.map((connector) => connector.key));
        for (const key of utils.StorageService.getKeys()) {
            if (key.startsWith('walletconnect') &&
                !keys.has(key.replace('walletconnect-', ''))) {
                localStorage.removeItem(key);
            }
        }
    }, [connectors]);
    return { clearAllWalletConnectSessions };
};

exports.useClearWalletConnectSessions = useClearWalletConnectSessions;
