'use client'
import { useCallback, useEffect } from 'react';
import { StorageService } from '@dynamic-labs/utils';
import { EMBEDDED_WALLET_SESSION_SETTINGS, EMBEDDED_WALLET_SECURE_BANNER } from '../../constants/localStorage.js';

const useClearWalletConnectSessions = ({ connectors }) => {
    const clearAllWalletConnectSessions = useCallback(() => {
        if (typeof window === 'undefined')
            return;
        for (const key of StorageService.getKeys()) {
            if (key.startsWith('walletconnect') ||
                key.startsWith('walletlink') ||
                key.startsWith('wc@2')) {
                localStorage.removeItem(key);
            }
        }
        // remove embedded wallet session iframe
        connectors === null || connectors === void 0 ? void 0 : connectors.forEach((connector) => {
            var _a, _b, _c;
            if ((_b = (_a = connector === null || connector === void 0 ? void 0 : connector.name) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === null || _b === void 0 ? void 0 : _b.startsWith('turnkey')) {
                (_c = connector
                    .getAuthenticatorHandler()) === null || _c === void 0 ? void 0 : _c.clear();
                StorageService.removeItem(EMBEDDED_WALLET_SESSION_SETTINGS);
                StorageService.removeItem(EMBEDDED_WALLET_SECURE_BANNER);
            }
        });
    }, [connectors]);
    // Clears orphaned wallet connect sessions
    useEffect(() => {
        if (typeof window === 'undefined')
            return;
        if (connectors.length === 0)
            return;
        const keys = new Set(connectors.map((connector) => connector.key));
        for (const key of StorageService.getKeys()) {
            if (key.startsWith('walletconnect') &&
                !keys.has(key.replace('walletconnect-', ''))) {
                localStorage.removeItem(key);
            }
        }
    }, [connectors]);
    return { clearAllWalletConnectSessions };
};

export { useClearWalletConnectSessions };
