'use client'
import { __awaiter } from '../../../../../_virtual/_tslib.js';
import { useRef, useCallback, useEffect } from 'react';
import { logger } from '../../../shared/logger.js';
import { setSessionValidation } from '../../../store/state/loadingAndLifecycle/loadingAndLifecycle.js';
import { useProjectSettings } from '../../../store/state/projectSettings/projectSettings.js';
import { handleStoreAndEnvironmentMismatch } from './handleStoreAndEnvironmentMismatch/handleStoreAndEnvironmentMismatch.js';
import { handleUserDataOutOfSync } from './handleUserDataOutOfSync/handleUserDataOutOfSync.js';
import { handleWalletInfoOutOfSync } from './handleWalletInfoOutOfSync/handleWalletInfoOutOfSync.js';

const useValidateSession = ({ environmentId, handleLogOut }) => {
    const didRunRef = useRef(false);
    const projectSettings = useProjectSettings();
    const logout = useCallback(
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    (reason, params) => __awaiter(void 0, void 0, void 0, function* () {
        logger.info(`Logging out due to invalid session - Reason: ${reason}`, Object.assign({}, params));
        return handleLogOut();
    }), [handleLogOut]);
    const validateSession = useCallback((projectSettings) => __awaiter(void 0, void 0, void 0, function* () {
        const params = {
            environmentId,
            logout,
            projectSettings,
        };
        yield Promise.all([
            handleStoreAndEnvironmentMismatch(params),
            handleUserDataOutOfSync(params),
            handleWalletInfoOutOfSync(params),
        ]);
        // Regardless of whether we logged out or not, session validation is now complete
        setSessionValidation(true);
    }), [logout, environmentId]);
    useEffect(() => {
        if (didRunRef.current || !projectSettings)
            return;
        didRunRef.current = true;
        validateSession(projectSettings);
    }, [validateSession, projectSettings]);
};

export { useValidateSession };
