'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var React = require('react');
var sdkApiCore = require('@dynamic-labs/sdk-api-core');
var utils = require('@dynamic-labs/utils');
var ErrorContainer = require('../../components/ErrorContainer/ErrorContainer.cjs');
var SocialRedirectContext = require('../../context/SocialRedirectContext/SocialRedirectContext.cjs');
var ViewContext = require('../../context/ViewContext/ViewContext.cjs');
var DefaultFooter = require('../../layout/DynamicAuthLayout/DefaultFooter/DefaultFooter.cjs');
var classNames = require('../../utils/functions/classNames/classNames.cjs');
var useAuthLayoutChecks = require('../../utils/hooks/useAuthLayoutChecks/useAuthLayoutChecks.cjs');
var useWalletItemActions = require('../../utils/hooks/useWalletItemActions/useWalletItemActions.cjs');
var FarcasterQrCodeView = require('../FarcasterQrCodeView/FarcasterQrCodeView.cjs');
var WalletList = require('../WalletList/WalletList.cjs');
var useErrorText = require('../../context/ErrorContext/hooks/useErrorText/useErrorText.cjs');
var LoginViewSection = require('./LoginViewSection/LoginViewSection.cjs');
var useLoginView = require('./useLoginView/useLoginView.cjs');
var showFarcasterQrCodeView = require('./utils/showFarcasterQrCodeView/showFarcasterQrCodeView.cjs');

const LoginView = () => {
    var _a;
    const { errorText } = useErrorText.useErrorText();
    const { pushView } = ViewContext.useViewContext();
    const { isWalletOnly, loginViewSections } = useLoginView.useLoginView();
    const { enabledSocialProviders } = SocialRedirectContext.useSocialRedirectContext();
    const { showDefaultFooter } = useAuthLayoutChecks.useAuthLayoutChecks();
    const { handleWalletItemClick } = useWalletItemActions.useWalletItemActions();
    const numOfWallets = ((_a = loginViewSections.find((section) => section.type === sdkApiCore.SdkViewSectionType.Wallet)) === null || _a === void 0 ? void 0 : _a.numOfItemsToDisplay) || 0;
    const renderViewSections = React.useMemo(() => loginViewSections.map((viewSection, index) => (jsxRuntime.jsx("div", { className: classNames.classNames('login-view__scroll__section', `login-view__scroll__section--${viewSection.type}`), children: jsxRuntime.jsx(LoginViewSection.LoginViewSection, { gotToWalletList: () => pushView('login-with-email-or-wallet-full-wallet-list'), index: index, viewSection: viewSection, walletCount: numOfWallets }) }, `${viewSection.type}__${index}`))), [loginViewSections, numOfWallets, pushView]);
    const errorElement = errorText && (jsxRuntime.jsx(ErrorContainer.ErrorContainer, { className: 'login-view__error-container', withIcon: false, children: errorText }));
    if (showFarcasterQrCodeView.showFarcasterQrCodeView(loginViewSections, enabledSocialProviders)) {
        return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [errorElement, jsxRuntime.jsx(FarcasterQrCodeView.FarcasterQrCodeView, {})] }));
    }
    if (isWalletOnly) {
        return (jsxRuntime.jsx(WalletList.WalletList, { onSelectWallet: handleWalletItemClick, showDefaultFooter: showDefaultFooter }));
    }
    const shouldShowFooter = utils.isMobile() && showDefaultFooter;
    return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [errorElement, jsxRuntime.jsx("div", { className: classNames.classNames('login-view__container', {
                    'login-view__container--error': Boolean(errorText),
                }), children: jsxRuntime.jsx("div", { className: 'login-view__scroll', "data-testid": 'login-view-scroll', children: renderViewSections }) }), shouldShowFooter && jsxRuntime.jsx(DefaultFooter.DefaultFooter, { hideBorder: true })] }));
};

exports.LoginView = LoginView;
